@@ -7,9 +7,12 @@ from dodfminer.extract.polished.acts.base import Atos
 
 
 class Retirements(Atos):
+    '''
+    Classe para atos de aposentadoria
+    '''
 
-    def __init__(self, file, backend, segmentation):
-        super().__init__(file, backend, segmentation)
+    def __init__(self, file, backend):
+        super().__init__(file, backend)
 
     def _regex_flags(self):
         return re.IGNORECASE
@@ -19,6 +22,11 @@ class Retirements(Atos):
         f_path += '/models/aposentadoria.pkl'
         return joblib.load(f_path)
 
+    def _load_seg_model(self):
+        f_path = os.path.dirname(__file__)
+        f_path += '/seg_models/aposentadoria.pkl'
+        return joblib.load(f_path)
+
     def _act_name(self):
         return "Aposentadoria"
 
@@ -28,7 +36,7 @@ class Retirements(Atos):
                 "Fundamento Legal", "Orgao", "Vigencia", "Matricula SIAPE"]
 
     def _rule_for_inst(self):
-        start = r"(APOSENTAR|CONCEDER\sAPOSENTADORIA,?\s?)"
+        start = r"(APOSENTAR[^-]|CONCEDER,\sAPOSENTADORIA|CONCEDER\sAPOSENTADORIA,?\s?)"
         body = r"([\s\S]*?"
         end = r"(?<!lei)\s(?:[0-9|\s]*?[.|-]\s?)+?"
         end2 = r"[0-9|\s]*/\s?[0-9|\s]*-?\s?[0-9|\s]*[.|,])"
@@ -54,6 +62,9 @@ class Retirements(Atos):
         return rules
 
 class RetAposentadoria(Atos):
+    '''
+    Classe para atos de retificação de aposentadoria
+    '''
 
     def __init__(self, file, backend):
         super().__init__(file, backend)
@@ -61,6 +72,11 @@ class RetAposentadoria(Atos):
     def _regex_flags(self):
         return re.IGNORECASE
 
+    def _load_model(self):
+        f_path = os.path.dirname(__file__)
+        f_path += '/models/efetivos_ret.pkl'
+        return joblib.load(f_path)
+
     def _act_name(self):
         return "Retificações de Aposentadoria"
 
@@ -90,7 +106,7 @@ class RetAposentadoria(Atos):
         data_dodf = r"dodf[\s\S]*?(?:[0-9]*?)"
         data_dodf2 = r"([0-9]*?[/|.][0-9]*?[/|.][0-9]*?)[,|\s]"
 
-        le = r"\sle[,|:|;]\s?([\s\S]*?),?\sleia[\s\S]*?"
+        le1 = r"\sle[,|:|;]\s?([\s\S]*?),?\sleia[\s\S]*?"
         le2 = r"[,|:|;]\s(?:[\s\S]*?)[.]\s"
 
         leia = r"\sle[,|:|;]\s?(?:[\s\S]*?),"
@@ -108,6 +124,6 @@ class RetAposentadoria(Atos):
                  "classe": r"(?:([^,]*?)\sclasse,)?(?(1)|classe\s([\s\S]*?),)",
                  "padrao": r"[p|P]adr[a|ã]o\s([\s\S]*?),",
                  "matricula_SIAPE": r"siape\sn?o?\s([\s\S]*?)[,| | .]",
-                 "informacao_errada": le+le2,
+                 "informacao_errada": le1+le2,
                  "informacao_corrigida": leia+leia2}
         return rules
