@@ -8,10 +8,10 @@ import pandas as pd
 
 from dodfminer.extract.polished.backend.regex import ActRegex
 from dodfminer.extract.polished.backend.ner import ActNER
-from dodfminer.extract.polished.segmentation.core import Segmentation
+from dodfminer.extract.polished.backend.seg import ActSeg
 
 
-class Atos(ActRegex, ActNER):
+class Atos(ActRegex, ActNER, ActSeg):
     """Base class for extracting an act and its proprieties to a dataframe.
 
     Note:
@@ -37,28 +37,24 @@ class Atos(ActRegex, ActNER):
 
     """
 
-    def __init__(self, file, backend='regex', segmentation=False):
+    def __init__(self, file_name, backend='regex'):
         self._backend = backend
         self._name = self._act_name()
-        super(Atos, self).__init__()
+        super().__init__()
 
         try:
-            fp = open(file, "r")
-            if segmentation:
-                self._text = Segmentation.extract_segments(fp.read(), self._name)
-            else:
-                self._text = fp.read()
-            fp.close()
-            self._file_name = file
-        except Exception as e:
-            print(e)
-            self._text = file
+            with open(file_name, "r", encoding='utf-8') as file:
+                self._text = file.read()
+                file.close()
+                self._file_name = file_name
+        except IOError:
+            self._text = file_name
             self._file_name = None
 
         self._acts_str = []
         self._columns = self._props_names()
 
-        self._raw_acts = self._extract_instances()
+        self._raw_acts = self._seg_function()
         self._acts = self._extract_props()
         self._data_frame = self._build_dataframe()
 
@@ -109,12 +105,13 @@ class Atos(ActRegex, ActNER):
             The dataframe created
         """
         if len(self._acts) > 0:
-            df = pd.DataFrame(self._acts)
+            data_frame = pd.DataFrame(self._acts)
             if self._backend == 'regex':
-                df.columns = self._columns
+                data_frame.columns = self._columns
             else:
-                df.columns = [x.capitalize() for x in df.columns]
-            return df
+                data_frame.columns = [x.capitalize()
+                                      for x in data_frame.columns]
+            return data_frame
         return pd.DataFrame()
 
     def _extract_props(self):
@@ -134,23 +131,3 @@ class Atos(ActRegex, ActNER):
                 raise NotImplementedError("Non-existent backend option")
             acts.append(act)
         return acts
-
-    def _extract_instances(self):
-        """Extract instances of an act.
-
-        Warning:
-            Instance must have an head and an body.
-
-        Returns:
-            All the instances of the act found.
-
-        """
-        instances = []
-        if self._backend == 'regex':
-            instances = self._regex_instances()
-        elif self._backend == 'ner':
-            instances = self._regex_instances()
-        else:
-            raise NotImplementedError("Non-existent backend option")
-
-        return instances
