@@ -6,8 +6,11 @@ from dodfminer.extract.polished.acts.base import Atos
 
 
 class NomeacaoComissionados(Atos):
+    '''
+        Classe para atos de nomeação de comissionados
+    '''
 
-    def __init__(self, file, backend, segmentation):
+    def __init__(self, file, backend):
         super().__init__(file, backend)
 
     def _act_name(self):
@@ -15,7 +18,12 @@ class NomeacaoComissionados(Atos):
 
     def _load_model(self):
         f_path = os.path.dirname(__file__)
-        f_path += '/models/nomeacao_ner.pkl'
+        f_path += '/models/comissionados_nome.pkl'
+        return joblib.load(f_path)
+
+    def _load_seg_model(self):
+        f_path = os.path.dirname(__file__)
+        f_path += '/seg_models/comissionados_nome.pkl'
         return joblib.load(f_path)
 
     def _props_names(self):
@@ -25,7 +33,7 @@ class NomeacaoComissionados(Atos):
     def _rule_for_inst(self):
         start = r"(NOMEAR)"
         body = r"([\s\S]*?)"
-        end = r"\.\s"
+        end = r"((\.\s)|(?=(EXONERAR|NOMEAR)))"
         return start + body + end
 
     def _prop_rules(self):
@@ -47,7 +55,11 @@ class NomeacaoComissionados(Atos):
                  "orgao": org + org2}
         return rules
 
+
 class NomeacaoEfetivos(Atos):
+    '''
+    Classe para atos de nomeação de efetivos
+    '''
 
     def __init__(self, file, backend):
         super().__init__(file, backend)
@@ -55,12 +67,42 @@ class NomeacaoEfetivos(Atos):
     def _act_name(self):
         return "Nomeação de Efetivos"
 
+    def _load_model(self):
+        f_path = os.path.dirname(__file__)
+        f_path += '/models/efetivos_nome.pkl'
+        return joblib.load(f_path)
+
+    def _load_seg_model(self):
+        f_path = os.path.dirname(__file__)
+        f_path += '/seg_models/efetivos_nome.pkl'
+        return joblib.load(f_path)
+
     def _props_names(self):
-        return ['tipo','edital_normativo','data_do_edital_normativo','DODF_edital_normativo','data_DODF_edital_normativo','edital_resultado_final','data_edital_resultado_final','cargo','especialiade','carreira','orgao','nome_candidato','classificacao','pne','sei','reposicionamento']
+        return [
+            'tipo',
+            'edital_normativo',
+            'data_do_edital_normativo',
+            'DODF_edital_normativo',
+            'data_DODF_edital_normativo',
+            'edital_resultado_final',
+            'data_edital_resultado_final',
+            'cargo',
+            'especialiade',
+            'carreira',
+            'orgao',
+            'nome_candidato',
+            'classificacao',
+            'pne',
+            'sei',
+            'reposicionamento'
+        ]
 
     def _rule_for_inst(self):
-        start = r"(NOMEAR\s)((?:[ao]s\scandidat[ao]s\sabaixo(?:[a-zA-Z_0-9,\s\/-\:\-\(\);]*).|(?:[ao]\scandidat[oa]\sabaixo(?:[a-zA-Z_0-9,\s\/-\:\-\(\)]*)))(?:\s[a-zA-Z_\s]*(?:deficiencia|especiais):(?:\s[\sA-Zo]+,\s?\d{1,4}o?;?)+)?(?:\s)?(?:[\r\n\t\f\sa-zA-Z_\s]*classificacao:(?:\s[\sA-Zo]+,\s?\d{1,4}o?[,;]?)+)?)"
-        body = ""
+        start = r"(NOMEAR\s)"
+        body = r"((?:[ao]s\scandidat[ao]s\sabaixo(?:([a-zA-Z_0-9,\s\/-\:\-\(\);](no?\.)?)*).|" +\
+            r"(?:[ao]\scandidat[oa]\sabaixo(?:([a-zA-Z_0-9,\s\/-\:\-\(\);](no?\.)?)*)))(?:\s[a-zA-Z_\s]*" +\
+            r"(?:deficiencia|especiais):(?:\s[\sA-Zo]+,\s?\d{1,4}o?;?)+)?(?:\s)?(?:[\r\n\t\f\sa-zA-Z_\s]*"+\
+            r"classificacao:(?:\s[\sA-Zo]+,\s?\d{1,4}o?[,;]?)+)?)"
         end = ""
         return start + body + end
 
