@@ -1,12 +1,17 @@
 """Regras regex para atos de Reversões."""
 
 import re
+import os
+import joblib
 from dodfminer.extract.polished.acts.base import Atos
 
 
 class Revertions(Atos):
+    '''
+        Classe com atos de reversão
+    '''
 
-    def __init__(self, text, backend, segmentation):
+    def __init__(self, text, backend):
         super().__init__(text, backend)
 
     def _regex_flags(self):
@@ -15,6 +20,16 @@ class Revertions(Atos):
     def _act_name(self):
         return "Reversão"
 
+    def _load_model(self):
+        f_path = os.path.dirname(__file__)
+        f_path += '/models/reversao.pkl'
+        return joblib.load(f_path)
+
+    def _load_seg_model(self):
+        f_path = os.path.dirname(__file__)
+        f_path += '/seg_models/reversao.pkl'
+        return joblib.load(f_path)
+
     def _props_names(self):
         return ["Tipo do Ato", "SEI", "Nome", "Matricula", "Cargo", "Classe",
                 "Padrao", "Quadro", "Fundamento Legal", "Orgao",
