@@ -1,5 +1,7 @@
 import re
+import os
 from typing import List, Match
+import joblib
 import pandas as pd
 import numpy as np
 from dodfminer.extract.polished.acts.base import Atos
@@ -45,6 +47,10 @@ TIPO_DOCUMENTO = r"(?i:portaria|ordem de servi.o|instru..o)"
 EMPTY_MATCH = r'(?!x)x'
 
 class SemEfeitoAposentadoria(Atos):
+    '''
+    Classe para atos que tornam aposentadoria sem efeito
+    '''
+
     _special_acts = [
         'data_documento',
         'tipo_edicao',
@@ -65,12 +71,12 @@ class SemEfeitoAposentadoria(Atos):
         "RETIFICAR",
     ]
 
-    def _pre_process_text(self, s):
+    def _pre_process_text(self, text):
         # Make sure words splitted accross lines are joined together
-        no_split_word = s.replace('-\n', '-')
+        no_split_word = text.replace('-\n', '-')
         return no_split_word.replace('\n', ' ')
 
-    def __init__(self, file, backend, segmentation, debug=False, extra_search=True,
+    def __init__(self, file, backend, debug=False, extra_search=True,
                  nlp=None, max_length=2000):
         self._max_length = max_length
         self._debug = debug
@@ -80,6 +86,16 @@ class SemEfeitoAposentadoria(Atos):
         self._nlp = nlp
         super().__init__(file, backend)
 
+    def _load_model(self):
+        f_path = os.path.dirname(__file__)
+        f_path += '/models/sem_efeito_apo.pkl'
+        return joblib.load(f_path)
+
+    def _load_seg_model(self):
+        f_path = os.path.dirname(__file__)
+        f_path += '/seg_models/sem_efeito_apo.pkl'
+        return joblib.load(f_path)
+
     def _act_name(self):
         return "Atos tornados sem efeito - aposentadoria"
 
@@ -264,7 +280,7 @@ class SemEfeitoAposentadoria(Atos):
             self._get_special_acts(acts)
         return acts
 
-    def _extract_instances(self) -> List[Match]:
+    def _regex_instances(self) -> List[Match]:
         found = self._find_instances()
         self._acts_str = found.copy()
         return found
